@@ -1,7 +1,7 @@
-/// \file IOHprofiler_all_problems.cpp
-/// \brief cpp file for class IOHprofiler_all_problems.
+/// \file IOHprofiler_all_suites.hpp
+/// \brief cpp file for class IOHprofiler_all_suites.
 ///
-/// A head file includes all problems of IOHprofiler.
+/// A head file includes all suites of IOHprofiler.
 ///
 /// \author Furong Ye
 /// \date 2019-06-27
@@ -11,7 +11,7 @@
 #include "IOHprofiler_PBO_suite.hpp"
 #include "IOHprofiler_BBOB_suite.hpp"
 
-#include "IOHprofiler_class_generator.hpp"
+#include "IOHprofiler_class_generator.h"
 
 static registerInFactory<IOHprofiler_suite<int>,PBO_suite> regPBO("PBO");
 static registerInFactory<IOHprofiler_suite<double>,BBOB_suite> regBBOB("BBOB");
