@@ -1,7 +1,11 @@
+#ifndef _IOHPROFILER_COMMON_CPP
+#define _IOHPROFILER_COMMON_CPP
+
 #include "IOHprofiler_common.h"
 
+/// \todo Add specific code for errors.
 void IOH_error(std::string error_info) {
-  std::cout << "IOH_ERROR_INFO : " << error_info << std::endl;
+  std::cerr << "IOH_ERROR_INFO : " << error_info << std::endl;
   exit(1);
 }
 
@@ -15,4 +19,6 @@ void IOH_log(std::string log_info) {
 
 void IOH_log(std::string log_info, std::ofstream &log_stream) {
   log_stream << "IOH_LOG_INFO : " << log_info << std::endl;
-}
\ No newline at end of file
+}
+
+#endif //IOHPROFILER_COMMON_CPP
\ No newline at end of file
