@@ -8,7 +8,7 @@
 #ifndef _F_LEADING_ONES_RUGGEDNESSONE_H
 #define _F_LEADING_ONES_RUGGEDNESSONE_H
 
-#include "IOHprofiler_problem.hpp"
+#include "IOHprofiler_problem.h"
 #include "wmodels.hpp"
 
 class LeadingOnes_Ruggedness1 : public IOHprofiler_problem<int> {
@@ -23,15 +23,11 @@ public:
     IOHprofiler_set_lowerbound(0);
     IOHprofiler_set_upperbound(1);
     IOHprofiler_set_best_variables(1);
-    Initilize_problem(dimension);
+    IOHprofiler_set_number_of_variables(dimension);
   }
   
   ~LeadingOnes_Ruggedness1() {}
 
-  void Initilize_problem(int dimension) {
-    IOHprofiler_set_number_of_variables(dimension);
-  }
-
   double internal_evaluate(const std::vector<int> &x) {
     
     int n = x.size();
@@ -52,4 +48,4 @@ public:
   }
 };
 
-#endif
\ No newline at end of file
+#endif
