@@ -18,7 +18,6 @@ public:
     IOHprofiler_set_number_of_objectives(1);
     IOHprofiler_set_lowerbound(0);
     IOHprofiler_set_upperbound(1);
-    IOHprofiler_set_best_variables(1);
     IOHprofiler_set_number_of_variables(dimension);
   }
 
@@ -54,7 +53,16 @@ public:
 
     IOHprofiler_set_optimal((double)optimal_value);
   }
-
+  
+  /// \fn void set_w_setting(const double dummy_para, const int epistasis_para, const int neutrality_para, const int ruggedness_para)
+  /// \brief A function to configure w-model layers.
+  /// \param dummy_para percentage of valid bits.
+  /// \param epistasis_para size of sub-string for epistasis
+  /// \param neutrality_para size of sub-string for neutrality
+  /// \param ruggedness_para gamma for ruggedness layper
+  ///
+  /// For details of w-model, please read https://www.sciencedirect.com/science/article/pii/S1568494619308099
+  /// and https://dl.acm.org/doi/pdf/10.1145/3205651.3208240
   void set_w_setting(const double dummy_para, const int epistasis_para, const int neutrality_para, const int ruggedness_para) {
     this->dummy_para = dummy_para;
     this->epistasis_para = epistasis_para;
@@ -66,7 +74,8 @@ public:
     std::vector<int> w_model_x;
     std::vector<int> tempX;
     int n;
-    /// dummy step
+    
+    /// dummy layer
     if (this->dummy_para > 0){
       n = this->dummy_info.size();
       w_model_x.reserve(n);
@@ -76,23 +85,27 @@ public:
     } else {
       w_model_x = x;
     }
-    /// neutrality
+    
+    // neutrality layer
     if (this->neutrality_para > 0) {
       tempX = w_model_x;
       layer_neutrality_compute(tempX,w_model_x,this->neutrality_para);
     } 
-    ///
+    
+    // epistasis layer
     if (this->epistasis_para > 0) {
       tempX = w_model_x;
       layer_epistasis_compute(tempX,w_model_x,this->epistasis_para);
     }
-    ///
+    
+    // base evaluate
     n = w_model_x.size();
     int result = 0;
     for (int i = 0; i != n; ++i) {
       result += w_model_x[i];
     }
 
+    // ruggedness layer
     if (this->ruggedness_para > 0) {
       result = this->ruggedness_info[result];
     }
